<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format">

    <xsl:template match="/">
        <fo:root>
            <fo:layout-master-set>
                <fo:simple-page-master margin-right="2cm"  margin-left="2cm"
                    margin-bottom="2cm" margin-top="2cm"
                    page-width="10.5cm"  page-height="15cm"
                    master-name="first">
                    <fo:region-body region-name="PageBody"/>
                    <fo:region-after region-name="footer" extent="0.2cm"/>
                </fo:simple-page-master>
            </fo:layout-master-set>
            
            <fo:page-sequence master-reference="first">

                <fo:static-content flow-name="footer">
                    <fo:block font-size="7pt" text-align="right" border-top="1pt dashed silver">
                        Page
                        <fo:page-number/>
                        sur
                        <fo:page-number-citation ref-id="theEnd"/>
                    </fo:block>
                </fo:static-content>
                <fo:flow flow-name="PageBody">
                    <xsl:apply-templates/>
                    <fo:block id="theEnd" />
                </fo:flow>
                
            </fo:page-sequence>
            
        </fo:root>
    </xsl:template>
    
<xsl:template match="biographie">
    <fo:block
        font-size="14pt" font-family="verdana" font-weight="bold" text-align="center" color="red"
        space-before="5mm" space-after="5mm"><xsl:apply-templates select="@prénom"/>&#160;
        <xsl:apply-templates select="@nom"/></fo:block>
    <fo:block
        font-size="10pt" font-family="verdana" font-weight="italic" text-align="center" color="black">
        Né le : <xsl:apply-templates select="@naissance"/></fo:block>
    <xsl:if test="@mort">
    <fo:block
        font-size="10pt" font-family="verdana" font-weight="italic" text-align="center" color="black">
        Mort le : <xsl:apply-templates select="@mort"/></fo:block>
    </xsl:if>
    <fo:block
        font-size="10pt" font-family="verdana" font-weight="italic" text-align="center" color="black">
        <xsl:apply-templates select="child::instrument"/></fo:block>  
        <fo:block
            font-size="10pt" font-family="verdana" font-weight="italic" text-align="center" color="black">
        Genre : <xsl:apply-templates select="child::genre"/></fo:block>    
    <fo:block text-align-last="center">
        <fo:leader
            leader-length="60%"
            leader-pattern="rule"
            rule-style="solid"
            rule-thickness="0.1mm" color="black"/>
    </fo:block>
    <xsl:apply-templates select="histoire"/>
    <fo:block text-align-last="center">
        <fo:leader
            leader-length="60%"
            leader-pattern="rule"
            rule-style="solid"
            rule-thickness="0.1mm" color="black"/>
    </fo:block>
    <xsl:apply-templates select="discographie"/>
</xsl:template>
    
    <xsl:template match="histoire">
        <fo:block
            font-size="14pt" font-family="verdana" font-weight="bold" text-align="center" color="red"
            space-before="5mm" space-after="5mm">Histoire</fo:block>
        <fo:block
            font-size="10pt" font-family="verdana" text-align="justify" color="black">
            <xsl:apply-templates/></fo:block>
    </xsl:template>
    
    <xsl:template match="histoire/groupe">
        <fo:inline color="DarkBlue"><xsl:value-of select="."/></fo:inline>
    </xsl:template>
    
    <xsl:template match="histoire/musicien">
        <fo:inline color="DarkBlue"><xsl:value-of select="./prénom"/>&#160;<xsl:value-of select="./nom"/></fo:inline>
    </xsl:template>
    
    <xsl:template match="histoire/genre | histoire/instrument | histoire/label">
        <fo:inline color="Gold"><xsl:value-of select="."/></fo:inline>
    </xsl:template>
    
    <xsl:template match="histoire/disque">
        <fo:inline color="Red"><xsl:value-of select="./titre"/></fo:inline>
    </xsl:template>
    
    <xsl:template match="discographie">
        <fo:block
            font-size="14pt" font-family="verdana" font-weight="bold" text-align="center" color="red"
            space-before="5mm" space-after="5mm">Discographie</fo:block>
        <fo:list-block><xsl:apply-templates/></fo:list-block>
    </xsl:template>
    
    <xsl:template match="disque">
    
        <fo:list-item>
            <fo:list-item-label>
                <fo:block
                    text-indent="5mm"
                    font-family="verdana" font-size="11pt">&#x2022;</fo:block>
            </fo:list-item-label>
            <fo:list-item-body>
                <fo:block
                    text-indent="10mm"
                    font-family="verdana" font-size="11pt">
                    <xsl:value-of select="@parution"/> : 
                    <xsl:value-of select="titre"/>
                </fo:block>
               <xsl:if test="musicien">
                <fo:block
                    text-indent="10mm"
                    font-family="verdana" font-size="11pt"><fo:list-block><xsl:apply-templates/></fo:list-block></fo:block>
               </xsl:if>
            </fo:list-item-body>
        </fo:list-item>
        
    </xsl:template>
    
    <xsl:template match="disque/titre"/>
    
    <xsl:template match="disque/musicien">
        <fo:list-item>
            <fo:list-item-label>
                <fo:block
                    text-indent="15mm"
                    font-family="verdana" font-size="10pt">&#x2022;</fo:block>
            </fo:list-item-label>
            <fo:list-item-body>
                <fo:block
                    text-indent="20mm"
                    font-family="verdana" font-size="10pt"><xsl:value-of select="prénom"/>&#160;
                    <xsl:value-of select="nom"/></fo:block>
                <xsl:if test="count(current())!=0">
                    <fo:list-block><xsl:apply-templates/></fo:list-block></xsl:if>
            </fo:list-item-body>
        </fo:list-item>
    </xsl:template>
    
    <xsl:template match="musicien/prénom | musicien/nom"/>
    
    <xsl:template match="discographie/disque/musicien/instruments/instrument">
        <fo:list-item>
            <fo:list-item-label>
                <fo:block
                    text-indent="25mm"
                    font-family="verdana" font-weight="italic" font-size="9pt">&#x2022;</fo:block>
            </fo:list-item-label>
            <fo:list-item-body>
                <fo:block
                    text-indent="30mm"
                    font-family="verdana" font-weight="italic" font-size="9pt"><xsl:value-of select="."/></fo:block>
            </fo:list-item-body>
        </fo:list-item>
    </xsl:template>
    
</xsl:stylesheet>
